pub struct DisconnectClient {
pub client: Entity,
pub reason: Text,
}Expand description
A [Command] to disconnect a Client with a displayed reason.
Fields
client: Entityreason: TextTrait Implementations
Sourceimpl Clone for DisconnectClient
impl Clone for DisconnectClient
Sourcefn clone(&self) -> DisconnectClient
fn clone(&self) -> DisconnectClient
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Command for DisconnectClient
impl Command for DisconnectClient
Sourcefn apply(self, world: &mut World)
fn apply(self, world: &mut World)
Applies this command, causing it to mutate the provided
world. Read morefn handle_error_with(
self,
error_handler: fn(BevyError, ErrorContext),
) -> impl Command<Out = ()>where
Self: Sized,
fn handle_error_with(
self,
error_handler: fn(BevyError, ErrorContext),
) -> impl Command<Out = ()>where
Self: Sized,
Takes a [
Command] that returns a Result and uses a given error handler function to convert it into
a [Command] that internally handles an error if it occurs and returns ().fn handle_error(self) -> impl Command<Out = ()>where
Self: Sized,
fn handle_error(self) -> impl Command<Out = ()>where
Self: Sized,
Takes a [
Command] that returns a Result and uses the fallback error handler function to convert it into
a [Command] that internally handles an error if it occurs and returns ().fn ignore_error(self) -> impl Command<Out = ()>where
Self: Sized,
fn ignore_error(self) -> impl Command<Out = ()>where
Self: Sized,
Takes a [
Command] that returns a Result and ignores any error that occurs.Sourceimpl Debug for DisconnectClient
impl Debug for DisconnectClient
Sourceimpl PartialEq for DisconnectClient
impl PartialEq for DisconnectClient
Sourcefn eq(&self, other: &DisconnectClient) -> bool
fn eq(&self, other: &DisconnectClient) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DisconnectClient