EntityRemoveBuf

Struct EntityRemoveBuf 

pub struct EntityRemoveBuf(/* private fields */);
Contains a list of Minecraft entities that need to be despawned. Entity IDs in this list will be despawned all at once at the end of the tick.

You should not need to use this directly under normal circumstances.

Implementations

Source

impl EntityRemoveBuf

pub fn push(&mut self, entity_id: i32)

pub fn send_and_clear<W: WritePacket>(&mut self, w: W)

Sends the entity remove packet and clears the buffer. Does nothing if the buffer is empty.