pub struct OldView {
pub old_pos: &'static OldPosition,
pub old_view_dist: &'static OldViewDistance,
}Fields
old_pos: &'static OldPositionold_view_dist: &'static OldViewDistanceTrait Implementations
Sourceimpl QueryData for OldView
impl QueryData for OldView
Sourceunsafe fn fetch<'__w, '__s>(
_state: &'__s Self::State,
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_entity: Entity,
_table_row: TableRow,
) -> Option<Self::Item<'__w, '__s>>
unsafe fn fetch<'__w, '__s>( _state: &'__s Self::State, _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _entity: Entity, _table_row: TableRow, ) -> Option<Self::Item<'__w, '__s>>
SAFETY: we call fetch for each member that implements Fetch.
Sourceconst IS_READ_ONLY: bool = true
const IS_READ_ONLY: bool = true
True if this query is read-only and may not perform mutable access.
Sourceconst IS_ARCHETYPAL: bool
const IS_ARCHETYPAL: bool
Returns true if (and only if) this query data relies strictly on archetypes to limit which
entities are accessed by the Query. Read more
Sourcetype ReadOnly = OldView
type ReadOnly = OldView
The read-only variant of this [
QueryData], which satisfies the [ReadOnlyQueryData] trait.Sourcetype Item<'__w, '__s> = OldViewItem<'__w, '__s>
type Item<'__w, '__s> = OldViewItem<'__w, '__s>
The item returned by this [
WorldQuery]
This will be the data retrieved by the query,
and is visible to the end user when calling e.g. Query<Self>::get.Sourcefn shrink<'__wlong: '__wshort, '__wshort, '__s>(
item: Self::Item<'__wlong, '__s>,
) -> Self::Item<'__wshort, '__s>
fn shrink<'__wlong: '__wshort, '__wshort, '__s>( item: Self::Item<'__wlong, '__s>, ) -> Self::Item<'__wshort, '__s>
This function manually implements subtyping for the query items.
Sourcefn provide_extra_access(
state: &mut Self::State,
access: &mut Access,
available_access: &Access,
)
fn provide_extra_access( state: &mut Self::State, access: &mut Access, available_access: &Access, )
Offers additional access above what we requested in
update_component_access.
Implementations may add additional access that is a subset of available_access
and does not conflict with anything in access,
and must update access to include that access. Read moreSourcefn iter_access(_state: &Self::State) -> impl Iterator<Item = EcsAccessType<'_>>
fn iter_access(_state: &Self::State) -> impl Iterator<Item = EcsAccessType<'_>>
Returns an iterator over the access needed by [
QueryData::fetch]. Access conflicts are usually
checked in [WorldQuery::update_component_access], but in certain cases this method can be useful to implement
a way of checking for access conflicts in a non-allocating way.Sourceimpl ReleaseStateQueryData for OldViewwhere
for<'__a> &'static OldPosition: ReleaseStateQueryData,
for<'__a> &'static OldViewDistance: ReleaseStateQueryData,
impl ReleaseStateQueryData for OldViewwhere
for<'__a> &'static OldPosition: ReleaseStateQueryData,
for<'__a> &'static OldViewDistance: ReleaseStateQueryData,
Sourcefn release_state<'__w>(_item: Self::Item<'__w, '_>) -> Self::Item<'__w, 'static>
fn release_state<'__w>(_item: Self::Item<'__w, '_>) -> Self::Item<'__w, 'static>
Releases the borrow from the query state by converting an item to have a
'static state lifetime.Sourceimpl WorldQuery for OldView
impl WorldQuery for OldView
Sourceunsafe fn set_archetype<'__w, '__s>(
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_state: &'__s Self::State,
_archetype: &'__w Archetype,
_table: &'__w Table,
)
unsafe fn set_archetype<'__w, '__s>( _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _state: &'__s Self::State, _archetype: &'__w Archetype, _table: &'__w Table, )
SAFETY: we call set_archetype for each member that implements Fetch
Sourceunsafe fn set_table<'__w, '__s>(
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_state: &'__s Self::State,
_table: &'__w Table,
)
unsafe fn set_table<'__w, '__s>( _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _state: &'__s Self::State, _table: &'__w Table, )
SAFETY: we call set_table for each member that implements Fetch
Sourceconst IS_DENSE: bool
const IS_DENSE: bool
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. Read more
Sourcetype Fetch<'__w> = OldViewFetch<'__w>
type Fetch<'__w> = OldViewFetch<'__w>
Per archetype/table state retrieved by this [
WorldQuery] to compute Self::Item for each entity.Sourcetype State = OldViewState
type State = OldViewState
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn shrink_fetch<'__wlong: '__wshort, '__wshort>(
fetch: <OldView as WorldQuery>::Fetch<'__wlong>,
) -> <OldView as WorldQuery>::Fetch<'__wshort>
fn shrink_fetch<'__wlong: '__wshort, '__wshort>( fetch: <OldView as WorldQuery>::Fetch<'__wlong>, ) -> <OldView as WorldQuery>::Fetch<'__wshort>
This function manually implements subtyping for the query fetches.
Sourceunsafe fn init_fetch<'__w, '__s>(
_world: UnsafeWorldCell<'__w>,
state: &'__s Self::State,
_last_run: Tick,
_this_run: Tick,
) -> <Self as WorldQuery>::Fetch<'__w>
unsafe fn init_fetch<'__w, '__s>( _world: UnsafeWorldCell<'__w>, state: &'__s Self::State, _last_run: Tick, _this_run: Tick, ) -> <Self as WorldQuery>::Fetch<'__w>
Creates a new instance of
Self::Fetch,
by combining data from the [World] with the cached Self::State.
Readonly accesses resources registered in [WorldQuery::update_component_access]. Read moreSourcefn update_component_access(state: &Self::State, _access: &mut FilteredAccess)
fn update_component_access(state: &Self::State, _access: &mut FilteredAccess)
Sourcefn init_nested_access(
state: &Self::State,
_system_name: Option<&str>,
_component_access_set: &mut FilteredAccessSet,
_world: UnsafeWorldCell<'_>,
)
fn init_nested_access( state: &Self::State, _system_name: Option<&str>, _component_access_set: &mut FilteredAccessSet, _world: UnsafeWorldCell<'_>, )
Adds any component accesses to other entities used by this [
WorldQuery]. Read moreSourcefn init_state(world: &mut World) -> OldViewState
fn init_state(world: &mut World) -> OldViewState
Creates and initializes a
State for this [WorldQuery] type.Sourcefn matches_component_set(
state: &Self::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( state: &Self::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
Sourcefn update_archetypes(_state: &mut Self::State, _world: UnsafeWorldCell<'_>)
fn update_archetypes(_state: &mut Self::State, _world: UnsafeWorldCell<'_>)
Called when the query state is updating its archetype cache.
This can be used by nested queries to update their internal archetype caches.
impl ArchetypeQueryData for OldViewwhere
for<'__a> &'static OldPosition: ArchetypeQueryData,
for<'__a> &'static OldViewDistance: ArchetypeQueryData,
impl Copy for OldView
impl IterQueryData for OldViewwhere
for<'__a> &'static OldPosition: IterQueryData,
for<'__a> &'static OldViewDistance: IterQueryData,
impl ReadOnlyQueryData for OldView
impl SingleEntityQueryData for OldViewwhere
for<'__a> &'static OldPosition: SingleEntityQueryData,
for<'__a> &'static OldViewDistance: SingleEntityQueryData,