pub struct UnloadEntityForClientMessage {
pub client: Entity,
pub entity_unloaded: Entity,
}Expand description
This message will be emitted when a entity is unloaded for a client (e.g when moving out of range of the entity).
Fields
client: EntityThe client to unload the entity for.
entity_unloaded: EntityThe entity ID of the entity that will be unloaded.